summaryrefslogtreecommitdiffstats
path: root/system/database/DB.php
diff options
context:
space:
mode:
authorAndrey Andreev <narf@devilix.net>2015-02-05 12:36:00 +0100
committerAndrey Andreev <narf@devilix.net>2015-02-05 12:36:00 +0100
commit74d0e23eae054c49bbf7d9d5c4738fa5a63754cf (patch)
treebf55970e20352119ce9241bdb70302264b569b43 /system/database/DB.php
parent395f92882afada9701ab2384772ce331ae9b3f9d (diff)
Allow a database to be loaded before controller instantiation
Diffstat (limited to 'system/database/DB.php')
-rw-r--r--system/database/DB.php23
1 files changed, 14 insertions, 9 deletions
diff --git a/system/database/DB.php b/system/database/DB.php
index d411b679e..8ea7ca6fa 100644
--- a/system/database/DB.php
+++ b/system/database/DB.php
@@ -61,18 +61,23 @@ function &DB($params = '', $query_builder_override = NULL)
}
include($file_path);
- // Make packages contain database config files
- foreach (get_instance()->load->get_package_paths() as $path)
+
+ // Make packages contain database config files,
+ // given that the controller instance already exists
+ if (class_exists('CI_Controller', FALSE))
{
- if ($path !== APPPATH)
+ foreach (get_instance()->load->get_package_paths() as $path)
{
- if (file_exists($file_path = $path.'config/'.ENVIRONMENT.'/database.php'))
- {
- include($file_path);
- }
- elseif (file_exists($file_path = $path.'config/database.php'))
+ if ($path !== APPPATH)
{
- include($file_path);
+ if (file_exists($file_path = $path.'config/'.ENVIRONMENT.'/database.php'))
+ {
+ include($file_path);
+ }
+ elseif (file_exists($file_path = $path.'config/database.php'))
+ {
+ include($file_path);
+ }
}
}
}